#!/usr/bin/python
# -*- coding: UTF-8 -*-
from abc import ABCMeta
class DublinCoreMetadata(object):
    __metaclass__ = ABCMeta
    def __init__(self):
        self.___dcContributor = None
        self.___dcCoverage = None
        self.___dcCreator = None
        self.___dcDate = None
        self.___dcDescription = None
        self.___dcFormat = None
        self.___dcIdentifier = None
        self.___dcLanguage = None
        self.___dcPublisher = None
        self.___dcRelation = None
        self.___dcRights = None
        self.___dcSource = None
        self.___dcSubject = None
        self.___dcTitle = None
        self.___dcType = None

    def getDCContributor(self):
        pass

    def getDCCoverage(self):
        pass

    def getDCCreator(self):
        pass

    def getDCDate(self):
        pass

    def getDCDescription(self):
        pass

    def getDCFormat(self):
        pass

    def getDCIdentifier(self):
        pass

    def getDCLanguage(self):
        pass

    def getDCPublisher(self):
        pass

    def getDCRelation(self):
        pass

    def getDCRights(self):
        pass

    def getDCSource(self):
        pass

    def getDCSubject(self):
        pass

    def getDCTitle(self):
        pass

    def getDCType(self):
        pass

